==> tencentcloud-sdk-java-3.0.32-sources.jar: com/tencentcloudapi/redis/v20180412/models/ResetPasswordRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.redis.v20180412.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class ResetPasswordRequest  extends AbstractModel{

    /**
    * 重置的密码
    */
    @SerializedName("Password")
    @Expose
    private String Password;

    /**
    * Redis实例ID
    */
    @SerializedName("InstanceId")
    @Expose
    private String InstanceId;

    /**
     * 获取重置的密码
     * @return Password 重置的密码
     */
    public String getPassword() {
        return this.Password;
    }

    /**
     * 设置重置的密码
     * @param Password 重置的密码
     */
    public void setPassword(String Password) {
        this.Password = Password;
    }

    /**
     * 获取Redis实例ID
     * @return InstanceId Redis实例ID
     */
    public String getInstanceId() {
        return this.InstanceId;
    }

    /**
     * 设置Redis实例ID
     * @param InstanceId Redis实例ID
     */
    public void setInstanceId(String InstanceId) {
        this.InstanceId = InstanceId;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Password", this.Password);
        this.setParamSimple(map, prefix + "InstanceId", this.InstanceId);

    }
}

==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/redis/v20180412/models/ResetPasswordRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.redis.v20180412.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class ResetPasswordRequest  extends AbstractModel{

    /**
    * Redis实例ID
    */
    @SerializedName("InstanceId")
    @Expose
    private String InstanceId;

    /**
    * 重置的密码（切换为免密实例时，可不传；其他情况必传）
    */
    @SerializedName("Password")
    @Expose
    private String Password;

    /**
    * 是否切换免密实例，false-切换为非免密码实例，true-切换为免密码实例；默认false
    */
    @SerializedName("NoAuth")
    @Expose
    private Boolean NoAuth;

    /**
     * 获取Redis实例ID
     * @return InstanceId Redis实例ID
     */
    public String getInstanceId() {
        return this.InstanceId;
    }

    /**
     * 设置Redis实例ID
     * @param InstanceId Redis实例ID
     */
    public void setInstanceId(String InstanceId) {
        this.InstanceId = InstanceId;
    }

    /**
     * 获取重置的密码（切换为免密实例时，可不传；其他情况必传）
     * @return Password 重置的密码（切换为免密实例时，可不传；其他情况必传）
     */
    public String getPassword() {
        return this.Password;
    }

    /**
     * 设置重置的密码（切换为免密实例时，可不传；其他情况必传）
     * @param Password 重置的密码（切换为免密实例时，可不传；其他情况必传）
     */
    public void setPassword(String Password) {
        this.Password = Password;
    }

    /**
     * 获取是否切换免密实例，false-切换为非免密码实例，true-切换为免密码实例；默认false
     * @return NoAuth 是否切换免密实例，false-切换为非免密码实例，true-切换为免密码实例；默认false
     */
    public Boolean getNoAuth() {
        return this.NoAuth;
    }

    /**
     * 设置是否切换免密实例，false-切换为非免密码实例，true-切换为免密码实例；默认false
     * @param NoAuth 是否切换免密实例，false-切换为非免密码实例，true-切换为免密码实例；默认false
     */
    public void setNoAuth(Boolean NoAuth) {
        this.NoAuth = NoAuth;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "InstanceId", this.InstanceId);
        this.setParamSimple(map, prefix + "Password", this.Password);
        this.setParamSimple(map, prefix + "NoAuth", this.NoAuth);

    }
}
